DROP TABLE IF EXISTS auslig CASCADE;
CREATE TABLE auslig
(
  rid serial NOT NULL,
  rast raster,
  filename text
)
WITH (
  OIDS=FALSE
);
ALTER TABLE auslig
  OWNER TO postgres;
GRANT ALL ON TABLE auslig TO postgres;
GRANT ALL ON TABLE auslig TO ulyssesusers;
GRANT SELECT ON TABLE auslig TO googleearth;

CREATE INDEX auslig_rast_gist
  ON auslig
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig CLUSTER ON auslig_rast_gist;

CREATE TABLE auslig_sd52(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((126 -16, 126 -11.095, 132 -11.095, 132 -16, 126 -16))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sd52_rast_gist
  ON auslig_sd52
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sd52 CLUSTER ON auslig_sd52_rast_gist;

CREATE TABLE auslig_sd53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -16, 132 -10.96, 137.28 -10.96, 137.28 -16, 132 -16))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sd53_rast_gist
  ON auslig_sd53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sd53 CLUSTER ON auslig_sd53_rast_gist;

CREATE TABLE auslig_sd54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((141.365 -16, 141.365 -9, 145.485 -9, 145.485 -16, 141.365 -16))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sd54_rast_gist
  ON auslig_sd54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sd54 CLUSTER ON auslig_sd54_rast_gist;

CREATE TABLE auslig_se51(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((120 -20, 120 -13.92, 126 -13.92, 126 -20, 120 -20))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_se51_rast_gist
  ON auslig_se51
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_se51 CLUSTER ON auslig_se51_rast_gist;

CREATE TABLE auslig_se52(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((126 -20, 126 -16, 132 -16, 132 -20, 126 -20))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_se52_rast_gist
  ON auslig_se52
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_se52 CLUSTER ON auslig_se52_rast_gist;

CREATE TABLE auslig_se53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -20, 132 -16, 138 -16, 138 -20, 132 -20))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_se53_rast_gist
  ON auslig_se53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_se53 CLUSTER ON auslig_se53_rast_gist;

CREATE TABLE auslig_se54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((138 -20, 138 -16, 144 -16, 144 -20, 138 -20))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_se54_rast_gist
  ON auslig_se54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_se54 CLUSTER ON auslig_se54_rast_gist;

CREATE TABLE auslig_se55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -20, 144 -16, 148.485 -16, 148.485 -20, 144 -20))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_se55_rast_gist
  ON auslig_se55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_se55 CLUSTER ON auslig_se55_rast_gist;

CREATE TABLE auslig_sf50(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((113.415 -24, 113.415 -19.58, 120 -19.58, 120 -24, 113.415 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf50_rast_gist
  ON auslig_sf50
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf50 CLUSTER ON auslig_sf50_rast_gist;

CREATE TABLE auslig_sf51(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((120 -24, 120 -20, 126 -20, 126 -24, 120 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf51_rast_gist
  ON auslig_sf51
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf51 CLUSTER ON auslig_sf51_rast_gist;

CREATE TABLE auslig_sf52(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((126 -24, 126 -20, 132 -20, 132 -24, 126 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf52_rast_gist
  ON auslig_sf52
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf52 CLUSTER ON auslig_sf52_rast_gist;

CREATE TABLE auslig_sf53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -24, 132 -20, 138 -20, 138 -24, 132 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf53_rast_gist
  ON auslig_sf53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf53 CLUSTER ON auslig_sf53_rast_gist;

CREATE TABLE auslig_sf54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((138 -24, 138 -20, 144 -20, 144 -24, 138 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf54_rast_gist
  ON auslig_sf54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf54 CLUSTER ON auslig_sf54_rast_gist;

CREATE TABLE auslig_sf55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -24, 144 -20, 152.4 -20, 152.4 -24, 144 -24))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sf55_rast_gist
  ON auslig_sf55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sf55 CLUSTER ON auslig_sf55_rast_gist;

CREATE TABLE auslig_sg50(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((112.9175 -28, 112.9175 -24, 120 -24, 120 -28, 112.9175 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg50_rast_gist
  ON auslig_sg50
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg50 CLUSTER ON auslig_sg50_rast_gist;

CREATE TABLE auslig_sg51(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((120 -28, 120 -24, 126 -24, 126 -28, 120 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg51_rast_gist
  ON auslig_sg51
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg51 CLUSTER ON auslig_sg51_rast_gist;

CREATE TABLE auslig_sg52(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((126 -28, 126 -24, 132 -24, 132 -28, 126 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg52_rast_gist
  ON auslig_sg52
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg52 CLUSTER ON auslig_sg52_rast_gist;

CREATE TABLE auslig_sg53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -28, 132 -24, 138 -24, 138 -28, 132 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg53_rast_gist
  ON auslig_sg53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg53 CLUSTER ON auslig_sg53_rast_gist;

CREATE TABLE auslig_sg54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((138 -28, 138 -24, 144 -24, 144 -28, 138 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg54_rast_gist
  ON auslig_sg54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg54 CLUSTER ON auslig_sg54_rast_gist;

CREATE TABLE auslig_sg55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -28, 144 -24, 150 -24, 150 -28, 144 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg55_rast_gist
  ON auslig_sg55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg55 CLUSTER ON auslig_sg55_rast_gist;

CREATE TABLE auslig_sg56(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((150 -28, 150 -24, 153.5475 -24, 153.5475 -28, 150 -28))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sg56_rast_gist
  ON auslig_sg56
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sg56 CLUSTER ON auslig_sg56_rast_gist;

CREATE TABLE auslig_sh50(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((113.58 -32, 113.58 -28, 120 -28, 120 -32, 113.58 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh50_rast_gist
  ON auslig_sh50
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh50 CLUSTER ON auslig_sh50_rast_gist;

CREATE TABLE auslig_sh51(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((120 -32, 120 -28, 126 -28, 126 -32, 120 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh51_rast_gist
  ON auslig_sh51
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh51 CLUSTER ON auslig_sh51_rast_gist;

CREATE TABLE auslig_sh52(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((126 -32.315, 126 -28, 132 -28, 132 -32.315, 126 -32.315))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh52_rast_gist
  ON auslig_sh52
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh52 CLUSTER ON auslig_sh52_rast_gist;

CREATE TABLE auslig_sh53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -32, 132 -28, 138 -28, 138 -32, 132 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh53_rast_gist
  ON auslig_sh53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh53 CLUSTER ON auslig_sh53_rast_gist;

CREATE TABLE auslig_sh54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((138 -32, 138 -28, 144 -28, 144 -32, 138 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh54_rast_gist
  ON auslig_sh54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh54 CLUSTER ON auslig_sh54_rast_gist;

CREATE TABLE auslig_sh55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -32, 144 -28, 150 -28, 150 -32, 144 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh55_rast_gist
  ON auslig_sh55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh55 CLUSTER ON auslig_sh55_rast_gist;

CREATE TABLE auslig_sh56(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((150 -32, 150 -28, 153.64 -28, 153.64 -32, 150 -32))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sh56_rast_gist
  ON auslig_sh56
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sh56 CLUSTER ON auslig_sh56_rast_gist;

CREATE TABLE auslig_si50(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((114.9675 -35.2025, 114.9675 -32, 120 -32, 120 -35.2025, 114.9675 -35.2025))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si50_rast_gist
  ON auslig_si50
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si50 CLUSTER ON auslig_si50_rast_gist;

CREATE TABLE auslig_si51(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((120 -34.4825, 120 -32, 126 -32, 126 -34.4825, 120 -34.4825))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si51_rast_gist
  ON auslig_si51
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si51 CLUSTER ON auslig_si51_rast_gist;

CREATE TABLE auslig_si53(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((132 -36.08, 132 -32, 138 -32, 138 -36.08, 132 -36.08))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si53_rast_gist
  ON auslig_si53
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si53 CLUSTER ON auslig_si53_rast_gist;

CREATE TABLE auslig_si54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((138 -36, 138 -32, 144 -32, 144 -36, 138 -36))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si54_rast_gist
  ON auslig_si54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si54 CLUSTER ON auslig_si54_rast_gist;

CREATE TABLE auslig_si55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -36, 144 -32, 148.5 -32, 148.5 -36, 144 -36))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si55_rast_gist
  ON auslig_si55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si55 CLUSTER ON auslig_si55_rast_gist;

CREATE TABLE auslig_si56(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((148.5 -36, 148.5 -32, 152.61 -32, 152.61 -36, 148.5 -36))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_si56_rast_gist
  ON auslig_si56
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_si56 CLUSTER ON auslig_si56_rast_gist;

CREATE TABLE auslig_sj54(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((139.43 -38.86, 139.43 -36, 144 -36, 144 -38.86, 139.43 -38.86))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sj54_rast_gist
  ON auslig_sj54
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sj54 CLUSTER ON auslig_sj54_rast_gist;

CREATE TABLE auslig_sj55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((144 -39.5275, 144 -36, 150.23 -36, 150.23 -39.5275, 144 -39.5275))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sj55_rast_gist
  ON auslig_sj55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sj55 CLUSTER ON auslig_sj55_rast_gist;

CREATE TABLE auslig_sk55(CONSTRAINT boundary CHECK (ST_intersects(rast, ST_GeomFromText('POLYGON ((143.8175 -43.7425, 143.8175 -39.5275, 148.4975 -39.5275, 148.4975 -43.7425, 143.8175 -43.7425))',4283))))
INHERITS(auslig);
CREATE INDEX auslig_sk55_rast_gist
  ON auslig_sk55
  USING gist
  (st_convexhull(rast))
  WITH (FILLFACTOR=100);
ALTER TABLE auslig_sk55 CLUSTER ON auslig_sk55_rast_gist;